@@ -3,38 +3,46 @@ package Catalyst::Action::RenderView;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.09';
 
 use base 'Catalyst::Action';
 
+use MRO::Compat;
 use Data::Visitor::Callback;
+use UNIVERSAL qw/can/;
 
 my %ignore_classes = ();
 
 sub execute {
     my $self = shift;
     my ($controller, $c ) = @_;
-    $self->NEXT::execute( @_ );
+    $self->next::method( @_ );
     
-    $c->config->{debug}->{ignore_classes} = [ qw/
+    $c->config->{'Action::RenderView'}->{ignore_classes} = 
+        ( ref($c->config->{'debug'}) eq 'HASH' ? $c->config->{'debug'}->{ignore_classes} : undef )
+        || [ qw/
         DBIx::Class::ResultSource::Table 
         DBIx::Class::ResultSourceHandle
-        / ] unless exists $c->config->{debug}->{ignore_classes};
+        DateTime
+        / ] unless exists $c->config->{'Action::RenderView'}->{ignore_classes};
 
-    $c->config->{debug}->{scrubber_func} = sub { $_='[' . ref($_) . ']' }
-        unless exists $c->config->{debug}->{scrubber_func};
+    $c->config->{'Action::RenderView'}->{scrubber_func} = 
+        ( ref($c->config->{'debug'}) eq 'HASH' ? $c->config->{'debug'}->{scrubber_func} : undef )
+        || sub { $_='[stringified to: ' .  $_ . ']' }
+        unless exists $c->config->{'Action::RenderView'}->{scrubber_func};
     
     if ($c->debug && $c->req->params->{dump_info}) {
         unless ( keys %ignore_classes ) {
-            foreach my $class (@{$c->config->{debug}->{ignore_classes}}) {
-                $ignore_classes{$class} = $c->config->{debug}->{scrub_replacement};
+            foreach my $class (@{$c->config->{'Action::RenderView'}->{ignore_classes}}) {
+                $ignore_classes{$class} = $c->config->{'Action::RenderView'}->{scrubber_func};
             }
         } 
-        Data::Visitor::Callback->new(
+        my $scrubber=Data::Visitor::Callback->new(
             "ignore_return_values"             => 1,
             "object"                           => "visit_ref",
             %ignore_classes,
-        )->visit( $c->stash );
+        );
+        $scrubber->visit( $c->stash );
         die('Forced debug - Scrubbed output');
     }
     
@@ -42,7 +50,7 @@ sub execute {
         $c->response->content_type( 'text/html; charset=utf-8' );
     }
     return 1 if $c->req->method eq 'HEAD';
-    return 1 if $c->response->body && length( $c->response->body );
+    return 1 if defined $c->response->body && length( $c->response->body );
     return 1 if scalar @{ $c->error } && !$c->stash->{template};
     return 1 if $c->response->status =~ /^(?:204|3\d\d)$/;
     my $view = $c->view() 
@@ -68,7 +76,7 @@ response body. It also allows you to pass C<dump_info=1> to the url in
 order to force a debug screen, while in debug mode.
 
 If you have more than one view, you can specify which one to use with
-the C<default_view> config setting (see L<Catalyst>'s C<$c->view($name)>
+the C<default_view> config setting (see L<Catalyst>'s C<$c-E<gt>view($name)>
 method).
 
 =head1 METHODS
@@ -92,18 +100,25 @@ When you force debug with dump_info=1, RenderView is capable of removing
 classes from the objects in your stash. By default it will replace any
 DBIx::Class resultsource objects with the class name, which cleans up the
 debug output considerably, but you can change what gets scrubbed by 
-setting a list of classes in $c->config->{debug}->{ignore_classes}.
+setting a list of classes in 
+$c->config->{'Action::RenderView'}->{ignore_classes}.
 For instance:
 
-    $c->config->{debug}->{ignore_classes}=[]; 
+    $c->config->{'Action::RenderView'}->{ignore_classes}=[]; 
     
 To disable the functionality. You can also set 
-config->{debug}->{scrubber_func} to change what it does with the 
+config->{'Action::RenderView'}->{scrubber_func} to change what it does with the 
 classes. For instance, this will undef it instead of putting in the 
 class name:
 
-    $c->config->{debug}->{scrubber_func}=sub { undef $_ }; 
+    $c->config->{'Action::RenderView'}->{scrubber_func}=sub { undef $_ }; 
 
+=head2 Deprecation notice
+
+This plugin used to be configured by setting C<< $c->config->{debug} >>.
+That configuration key is still supported in this release, but is 
+deprecated, please use the C< 'Action::RenderView' > namespace as shown 
+above for configuration in new code.
 
 =head1 EXTENDING
 
